[x264-devel] commit: Fix bug in VBV lookahead + no MB-tree (Jason Garrett-Glaser )

git version control git at videolan.org
Wed Aug 19 04:53:59 CEST 2009


x264 | branch: master | Jason Garrett-Glaser <darkshikari at gmail.com> | Tue Aug 18 19:25:45 2009 -0700| [5e9ae4cb8de4a95a567c6dbfdbaaf8138e695589] | committer: Jason Garrett-Glaser 

Fix bug in VBV lookahead + no MB-tree
I-frames need to have VBV lookahead run on them as well.

> http://git.videolan.org/gitweb.cgi/x264.git/?a=commit;h=5e9ae4cb8de4a95a567c6dbfdbaaf8138e695589
---

 encoder/slicetype.c |    7 ++++---
 1 files changed, 4 insertions(+), 3 deletions(-)

diff --git a/encoder/slicetype.c b/encoder/slicetype.c
index af3d748..1dc1c2b 100644
--- a/encoder/slicetype.c
+++ b/encoder/slicetype.c
@@ -892,7 +892,8 @@ void x264_slicetype_decide( x264_t *h )
     }
     else if( (h->param.i_bframe && h->param.i_bframe_adaptive)
              || h->param.i_scenecut_threshold
-             || h->param.rc.b_mb_tree )
+             || h->param.rc.b_mb_tree
+             || (h->param.rc.i_vbv_buffer_size && h->param.rc.i_lookahead) )
         x264_slicetype_analyse( h, 0 );
 
     for( bframes = 0;; bframes++ )
@@ -950,8 +951,8 @@ int x264_rc_analyse_slice( x264_t *h )
     if( IS_X264_TYPE_I(h->fenc->i_type) )
     {
         p1 = b = 0;
-        /* For MB-tree, we have to perform propagation analysis on I-frames too. */
-        if( h->param.rc.b_mb_tree )
+        /* For MB-tree and VBV lookahead, we have to perform propagation analysis on I-frames too. */
+        if( h->param.rc.b_mb_tree || (h->param.rc.i_vbv_buffer_size && h->param.rc.i_lookahead) )
         {
             h->frames.last_nonb = h->fenc;
             x264_slicetype_analyse( h, 1 );



More information about the x264-devel mailing list